@@ -1,8 +1,8 @@
 //! Web Socket Actor for Actix Web
-use crate::*;
 use actix::prelude::*;
 use actix::{Actor, StreamHandler};
 use actix_web_actors::ws;
+use anyhow::Context;
 use std::time::{Duration, Instant};
 use tokio::sync::watch;
 
